==> speech-tools_1.0.1.orig.tar.gz: speech_tools/include/EST_string_aux.h <==
/*************************************************************************/
/*                                                                       */
/*                Centre for Speech Technology Research                  */
/*                     University of Edinburgh, UK                       */
/*                     Copyright (c) 1994,1995,1996                      */
/*                        All Rights Reserved.                           */
/*                                                                       */
/*  Permission to use, copy, modify, distribute this software and its    */
/*  documentation for research, educational and individual use only, is  */
/*  hereby granted without fee, subject to the following conditions:     */
/*   1. The code must retain the above copyright notice, this list of    */
/*      conditions and the following disclaimer.                         */
/*   2. Any modifications must be clearly marked as such.                */
/*   3. Original authors' names are not deleted.                         */
/*  This software may not be used for commercial purposes without        */
/*  specific prior written permission from the authors.                  */
/*                                                                       */
/*  THE UNIVERSITY OF EDINBURGH AND THE CONTRIBUTORS TO THIS WORK        */
/*  DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING      */
/*  ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT   */
/*  SHALL THE UNIVERSITY OF EDINBURGH NOR THE CONTRIBUTORS BE LIABLE     */
/*  FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES    */
/*  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN   */
/*  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,          */
/*  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF       */
/*  THIS SOFTWARE.                                                       */
/*                                                                       */
/*************************************************************************/
/*                    Author :  Paul Taylor                              */
/*                    Date   :  April 1994                               */
/*-----------------------------------------------------------------------*/
/*            Utility EST_String Functions header file                   */
/*                                                                       */
/*=======================================================================*/

#ifndef __EST_STRING_AUX_H__
#define __EST_STRING_AUX_H__

#include "EST_TList.h"
#include "EST_String.h"
#include "EST_types.h"
#include "EST_rw_status.h"

void StringtoStrList(EST_String s, EST_StrList &l, EST_String sep="");
EST_read_status load_StrList(EST_String filename, EST_StrList &l);
EST_write_status save_StrList(EST_String filename, EST_StrList &l, 
			      EST_String style="words");


void strip_quotes(EST_String &s, const EST_String quote_char="\"");

// makes EST_String from integer.
EST_String itoString(int n); 
// makes EST_String from float, with variable precision
EST_String ftoString(float n, int pres=3, int width=0, int l=0); 

// strips path off front of filename
EST_String basename(EST_String full, EST_String ext=""); 
int strlist_member(const EST_StrList &l,const EST_String &s);
int ilist_member(const EST_IList &l,int i);

#endif // __EST_STRING_AUX_H__

==> speech-tools_1.1.0.orig.tar.gz: speech_tools/include/EST_string_aux.h <==
/*************************************************************************/
/*                                                                       */
/*                Centre for Speech Technology Research                  */
/*                     University of Edinburgh, UK                       */
/*                     Copyright (c) 1994,1995,1996                      */
/*                        All Rights Reserved.                           */
/*                                                                       */
/*  Permission to use, copy, modify, distribute this software and its    */
/*  documentation for research, educational and individual use only, is  */
/*  hereby granted without fee, subject to the following conditions:     */
/*   1. The code must retain the above copyright notice, this list of    */
/*      conditions and the following disclaimer.                         */
/*   2. Any modifications must be clearly marked as such.                */
/*   3. Original authors' names are not deleted.                         */
/*  This software may not be used for commercial purposes without        */
/*  specific prior written permission from the authors.                  */
/*                                                                       */
/*  THE UNIVERSITY OF EDINBURGH AND THE CONTRIBUTORS TO THIS WORK        */
/*  DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING      */
/*  ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT   */
/*  SHALL THE UNIVERSITY OF EDINBURGH NOR THE CONTRIBUTORS BE LIABLE     */
/*  FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES    */
/*  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN   */
/*  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,          */
/*  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF       */
/*  THIS SOFTWARE.                                                       */
/*                                                                       */
/*************************************************************************/
/*                    Author :  Paul Taylor                              */
/*                    Date   :  April 1994                               */
/*-----------------------------------------------------------------------*/
/*            Utility EST_String Functions header file                   */
/*                                                                       */
/*=======================================================================*/

#ifndef __EST_STRING_AUX_H__
#define __EST_STRING_AUX_H__

#include "EST_TList.h"
#include "EST_String.h"
#include "EST_types.h"
#include "EST_rw_status.h"

void StringtoStrList(EST_String s, EST_StrList &l, EST_String sep="");
void BracketStringtoStrList(EST_String s, EST_StrList &l, EST_String sep="");

EST_read_status load_StrList(EST_String filename, EST_StrList &l);
EST_write_status save_StrList(EST_String filename, EST_StrList &l, 
			      EST_String style="words");


void strip_quotes(EST_String &s, const EST_String quote_char="\"");

// makes EST_String from integer.
EST_String itoString(int n); 
// makes EST_String from float, with variable precision
EST_String ftoString(float n, int pres=3, int width=0, int l=0); 

int StrListtoIList(EST_StrList &s, EST_IList &il);
int StrListtoFList(EST_StrList &s, EST_FList &il);

// strips path off front of filename
EST_String basename(EST_String full, EST_String ext=""); 

int ilist_member(const EST_IList &l,int i);
int ilist_index(const EST_IList &l,int i);

int strlist_member(const EST_StrList &l,const EST_String &s);
int strlist_index(const EST_StrList &l,const EST_String &s);

#endif // __EST_STRING_AUX_H__
